From: Neil Brown <neilb@cse.unsw.edu.au>

If programs like mount use /proc/partitions to find filesystems based on
labels, then surely we want md devices in there as they often contain
filesystems.

If the problem is that mount-by-label takes forever with removable media
then surely the "right" approch is the following patch, and then actually
set this flag on the "floppy.c" device.  (It is already set for ide-floppy
and sd devices).



---

 25-akpm/drivers/block/genhd.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff -puN drivers/block/genhd.c~proc-partitions-omit-removable-media drivers/block/genhd.c
--- 25/drivers/block/genhd.c~proc-partitions-omit-removable-media	Tue Jan 27 18:06:59 2004
+++ 25-akpm/drivers/block/genhd.c	Tue Jan 27 18:06:59 2004
@@ -260,8 +260,8 @@ static int show_partition(struct seq_fil
 	if (&sgp->kobj.entry == block_subsys.kset.list.next)
 		seq_puts(part, "major minor  #blocks  name\n\n");
 
-	/* Don't show non-partitionable devices or empty devices */
-	if (!get_capacity(sgp) || sgp->minors == 1)
+	/* Don't show removable devices or empty devices */
+	if (!get_capacity(sgp) || (sgp->flags & GENHD_FL_REMOVABLE))
 		return 0;
 
 	/* show the full disk and all non-0 size partitions of it */

_